Space Shuttle Autolanding Data Base

# Info on Space Shuttle Autolanding Data Base

    1. Title: Space Shuttle Autolanding Domain

    2. Sources:
        (a) Original source: unknown
            -- NASA: Mr. Roger Burke's autolander design team
        (b) Donor: Bojan Cestnik
                    Jozef Stefan Institute
                    Jamova 39
                    61000 Ljubljana
                    Yugoslavia (tel.: (38)(+61) 214-399 ext.287)
        (c) Date: November 1988

    3. Past Usage: (several, it appears)
         Example: Michie,D. (1988).  The Fifth Generation's Unbridged Gap.
                  In Rolf Herken (Ed.) The Universal Turing Machine: A
                  Half-Century Survey, 466-489, Oxford University Press.

    4. Relevant Information:
         This is a tiny database.  Michie reports that Burke's group used
         RULEMASTER to generate comprehendable rules for determining
         the conditions under which an autolanding would be preferable to
         manual control of the spacecraft.

    5. Number of Instances: 15

    6. Number of Attributes: 7 (including the class attribute)

    7. Attribute Information:
        1. Class: noauto, auto
           -- that is, advise using manual/automatic control
        2. STABILITY: stab, xstab
        3. ERROR: XL, LX, MM, SS
        4. SIGN: pp, nn
        5. WIND: head, tail
        6. MAGNITUDE: Low, Medium, Strong, OutOfRange
        7. VISIBILITY: yes, no

    8. Missing Attribute Values:
       -- none
       -- but several "don't care" values: (denoted by "*")
             Attribute Number:   Number of Don't Care Values:
                            2:   2
                            3:   3
                            4:   8
                            5:   8
                            6:   5
                            7:   0

    9. Class Distribution:
        1. Use noauto control: 6
        2. Use automatic control: 9